==> artelogic_text_recognition-1.0.1.tgz: package/src/Ocr.ts <==
import {createWorker, PSM, ImageLike, Page, Word, Bbox, Line} from 'tesseract.js';

type ProgressListener = (event: { status: string }) => void;
type AppendHtmlOptions = {
    adjustFontSize?: boolean;
    scale?: number;
}

export default class Ocr {
    data: Page = null;
    language: string = null;
    progressListeners: ProgressListener[] = []
    minFontSize = 2;

    constructor(language) {
        this.language = language;
    }

    addProgressListener(listener: ProgressListener) {
        this.progressListeners.push(listener);
    }

    removeProgressListener(listener: ProgressListener) {
        this.progressListeners = this.progressListeners.filter(item => item !== listener);
    }

    /**
     * Parse image with tesseract
     *
     * @param {ImageLike} image The image instance.
     */
    async parseImage(image: ImageLike) {
        const worker = createWorker({
            logger: m => {
                this.progressListeners.forEach(callback => {
                    callback(m)
                })
            },
        });
        await worker.load();
        await worker.loadLanguage(this.language);
        await worker.initialize(this.language);
        await worker.setParameters({
            tessedit_pageseg_mode: PSM.AUTO_ONLY,
        });
        const {data} = await worker.recognize(image);
        this.data = data;
        await worker.terminate();

        console.log(this.data);
    }

    private updateTextSize(el: HTMLElement) {
        const wrap = document.createElement('span');
        document.body.appendChild(wrap);

        wrap.innerHTML = el.textContent.trim();
        const height = parseInt(el.style.height.replace('px', ''));
        const width = parseInt(el.style.width.replace('px', ''));
        let fontSize = height;
        if (fontSize > this.minFontSize) {
            wrap.style.fontSize = `${fontSize}px`;
            const fontSizeH = fontSize * height / wrap.offsetHeight;
            const fontSizeW = fontSize * width / wrap.offsetWidth;
            fontSize = fontSizeH < fontSizeW ? fontSizeH : fontSizeW;
        }
        if (fontSize < this.minFontSize) {
            fontSize = this.minFontSize;
        }
        el.style.fontSize = `${fontSize}px`;

        wrap.remove();
    }

    private updatePosition(el: HTMLElement, bbox: Bbox, scale: number) {
        const {x0, x1, y0, y1} = bbox;
        el.style.position = 'absolute';
        el.style.left = `${x0 * scale}px`;
        el.style.top = `${y0 * scale}px`;
        el.style.width = `${(x1 - x0) * scale}px`;
        el.style.height = `${(y1 - y0) * scale}px`;
    }

    private mapWords(words: Word[], scale: number, adjustFontSize: boolean) {
        const wordElementsList: HTMLElement[] = [];
        words.forEach(word => {
            const {bbox, text} = word;
            if (text.trim().length === 0) return;

            const el = document.createElement('span');
            el.innerText = text;

            this.updatePosition(el, bbox, scale);
            if (adjustFontSize) {
                this.updateTextSize(el);
            }

            wordElementsList.push(el);
        })

        return wordElementsList;
    }

    /**
     * Append generated html to the container.
     *
     * @param {HTMLElement} container The container where elements should append.
     * @param {AppendHtmlOptions} options The options for customization.
     */
    appendHtml(container: HTMLElement, {adjustFontSize = true, scale = 1}: AppendHtmlOptions = {}) {
        if (!this.data.hocr) return;

        let elements: HTMLElement[] = []
        this.data.lines.forEach((line: Line) => {
            elements = [...elements, ...this.mapWords(line.words, scale, adjustFontSize)]
        })
        elements.forEach(element => {
            container.appendChild(element)
        })
    }

    getBlocksInfo() {
    }
}

==> artelogic_text_recognition-1.0.2.tgz: package/src/Ocr.ts <==
import {createWorker, PSM, ImageLike, Page, Word, Bbox, Line} from 'tesseract.js';

type ProgressListener = (event: { status: string }) => void;
type AppendHtmlOptions = {
    adjustFontSize?: boolean;
    scale?: number;
}
type Options = {
    language?: string,
    lineClassName?: string,
    wordClassName?: string
}

export default class Ocr {
    data: Page = null;
    language: string = null;
    lineClassName: string = '';
    wordClassName: string = '';
    progressListeners: ProgressListener[] = []
    minFontSize = 2;

    constructor({language = 'eng', lineClassName = '', wordClassName = ''}: Options = {}) {
        this.language = language;
        this.lineClassName = lineClassName;
        this.wordClassName = wordClassName;
    }

    addProgressListener(listener: ProgressListener) {
        this.progressListeners.push(listener);
    }

    removeProgressListener(listener: ProgressListener) {
        this.progressListeners = this.progressListeners.filter(item => item !== listener);
    }

    /**
     * Parse image with tesseract
     *
     * @param {ImageLike} image The image instance.
     */
    async parseImage(image: ImageLike) {
        const worker = createWorker({
            logger: m => {
                this.progressListeners.forEach(callback => {
                    callback(m)
                })
            },
        });
        await worker.load();
        await worker.loadLanguage(this.language);
        await worker.initialize(this.language);
        await worker.setParameters({
            tessedit_pageseg_mode: PSM.AUTO_ONLY,
        });
        const {data} = await worker.recognize(image);
        this.data = data;
        await worker.terminate();
    }

    private updateTextSize(el: HTMLElement) {
        const wrap = document.createElement('span');
        document.body.appendChild(wrap);

        wrap.innerHTML = el.textContent.trim();
        const height = parseInt(el.style.height.replace('px', ''));
        const width = parseInt(el.style.width.replace('px', ''));
        let fontSize = height;
        if (fontSize > this.minFontSize) {
            wrap.style.fontSize = `${fontSize}px`;
            const fontSizeH = fontSize * height / wrap.offsetHeight;
            const fontSizeW = fontSize * width / wrap.offsetWidth;
            fontSize = fontSizeH < fontSizeW ? fontSizeH : fontSizeW;
        }
        if (fontSize < this.minFontSize) {
            fontSize = this.minFontSize;
        }
        el.style.fontSize = `${fontSize}px`;

        wrap.remove();
    }

    private updatePosition(el: HTMLElement, bbox: Bbox, scale: number, parentBbox?: Bbox) {
        const {x0, x1, y0, y1} = bbox;
        el.style.position = 'absolute';
        el.style.left = `${parentBbox ? (parentBbox.x0 * scale) : (x0 * scale)}px`;
        el.style.top = `${parentBbox ? 0 : (y0 * scale)}px`;
        el.style.width = `${(x1 - x0) * scale}px`;
        el.style.height = `${(y1 - y0) * scale}px`;
    }

    private mapWords(words: Word[], scale: number, adjustFontSize: boolean, parentBbox: Bbox) {
        const wordElementsList = [];

        for (let i = 0; i < words.length; i++) {
            const {bbox, text} = words[i];
            const nextBboxX = i < words.length - 1 ? words[i + 1].bbox.x0 : bbox.x1;

            if (!text.trim().length) continue;

            const el = document.createElement('span');
            el.innerText = text;
            if (this.wordClassName.length) {
                el.classList.add(this.wordClassName);
            }

            const elementBbox = {x0: bbox.x0, x1: nextBboxX, y0: parentBbox.y0, y1: parentBbox.y1}

            this.updatePosition(el, elementBbox, scale, {
                x0: bbox.x0 - parentBbox.x0,
                x1: bbox.x1 - parentBbox.x1,
                y0: bbox.y0 - parentBbox.y0,
                y1: bbox.y1 - parentBbox.y1
            });
            if (adjustFontSize) {
                this.updateTextSize(el)
            }

            wordElementsList.push(el);
        }

        return wordElementsList;
    }

    private mapLine(line: Line, scale: number, adjustFontSize: boolean) {
        const {bbox, words} = line;

        const el = document.createElement('span');
        if (this.lineClassName.length) {
            el.classList.add(this.lineClassName);
        }
        this.updatePosition(el, bbox, scale);

        const wordElements = this.mapWords(words, scale, adjustFontSize, bbox);

        if (!wordElements.length) return null;

        wordElements.forEach(word => {
            el.appendChild(word);
        })

        return el;
    }

    /**
     * Append generated html to the container.
     *
     * @param {HTMLElement} container The container where elements should append.
     * @param {AppendHtmlOptions} options The options for customization.
     */
    appendHtml(container: HTMLElement, {adjustFontSize = true, scale = 1}: AppendHtmlOptions = {}) {
        if (!this.data.hocr) return;

        let elements: HTMLElement[] = []
        this.data.lines.forEach((line: Line) => {
            const mappedLine = this.mapLine(line, scale, adjustFontSize);
            if (mappedLine) {
                elements = [...elements, mappedLine]
            }
        })
        elements.forEach(element => {
            container.appendChild(element)
        })
    }

    getBlocksInfo() {
    }
}
